spoon.messaging.decorators

Package spoon :: Package messaging :: Module decorators |
[hide private]
[frames] | no frames]

# Module decorators

source code

Classes | [hide private]
`` | receive The receive decorator can be used to decorate functions and static methods (NOT methods of class instances) that should receive messages of a given type.
`` | handleMsg The receive decorator can be used to decorate functions and static methods (NOT methods of class instances) that should receive messages of a given type.